/* Import (extern) header for application - AppBuilder 2.01  */

#include "abdefine.h"

extern ApEventLink_t AbInternalLinks[];

extern ApWindowLink_t base;
extern ApWindowLink_t print_win;
extern ApWidget_t AbWidgets[ 5 ];


#ifdef __cplusplus
extern "C" {
#endif
int setup( PtWidget_t *widget, ApInfo_t *data, PtCallbackInfo_t *cbinfo );
int text_activate( PtWidget_t *widget, ApInfo_t *data, PtCallbackInfo_t *cbinfo );
int web_status( PtWidget_t *widget, ApInfo_t *data, PtCallbackInfo_t *cbinfo );
#ifdef __cplusplus
}
#endif
