/* Link header for application - AppBuilder 2.01  */

extern ApContext_t AbContext;

ApWindowLink_t base = {
	"base.wgtw",
	&AbContext,
	AbLinks_base, 0, 3
	};

ApWindowLink_t print_win = {
	"print_win.wgtw",
	&AbContext,
	NULL, 4, 0
	};

