/* Define header for application - AppBuilder 2.01  */

/* Internal Module Links */
extern const int ABI_print_win;
#define ABM_print_win                        &AbInternalLinks[ABI_print_win]

/* 'base' Window link */
extern const int ABN_base;
#define ABW_base                             AbGetABW( ABN_base )
extern const int ABN_text;
#define ABW_text                             AbGetABW( ABN_text )
extern const int ABN_web_client;
#define ABW_web_client                       AbGetABW( ABN_web_client )
extern const int ABN_display_b;
#define ABW_display_b                        AbGetABW( ABN_display_b )

/* 'print_win' Window link */
extern const int ABN_print_win;
#define ABW_print_win                        AbGetABW( ABN_print_win )

#define AbGetABW( n ) ( AbWidgets[ n ].wgt )

#define AB_OPTIONS "s:x:y:h:w:S:"
