/* Variables header for application - AppBuilder 2.01  */

/* Internal Module Links */
const int ABI_print_win = 0;

/* 'base' Window link */
const int ABN_base = 0;
const int ABN_text = 1;
const int ABN_web_client = 2;
const int ABN_display_b = 3;

/* 'print_win' Window link */
const int ABN_print_win = 4;

